# Deal

```{include} ../README.md
```

```{eval-rst}

.. toctree::
    :maxdepth: 1
    :caption: Getting started

    basic/intro
    basic/motivation
    basic/refs

.. toctree::
    :maxdepth: 1
    :caption: Writing contracts

    basic/values
    basic/exceptions
    basic/side-effects

.. toctree::
    :maxdepth: 1
    :caption: Checking contracts

    basic/runtime
    basic/tests
    basic/linter
    basic/verification
    basic/crosshair

.. toctree::
    :maxdepth: 1
    :caption: Dive deeper

    details/contracts
    details/module_load
    details/dispatch
    details/docs
    details/stubs
    details/tests
    details/recipes
    details/examples
    details/cli
    details/api
```
